const {
  ApiOrderDetail,
  ApiOrderCancel,
  ApiSendOrder,
  ApiOrderPay,
  ApiFinishOrder
} = require("../../http/api")
const {
  wxGet,
  wxPost
} = require("../../http/network")
const {
  showToast
} = require("../../utils/common")

const app = getApp()

// pages/order/order-detail.js
Page({

  /**
   * 页面的初始数据
   */
  data: {
    id: 0,
    data: null,
    admin: false,
    overlayVisible: false,
    price: null,
    roleType: app.globalData.roleType,
    canFixDisPatch: true
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad(options) {
    let id = options.id
    let admin = options.admin
    if (admin) {
      this.setData({
        admin: true,
        roleType: app.globalData.roleType
      })
    }
    this.setData({
      id
    })
    this.getData()
  },
  getData() {
    wxGet(ApiOrderDetail + this.data.id).then(res => {
      
      var start_date = new Date(res.data.expectArrivalTime.replace(/-/g, "/"))
      var end_date = new Date()
      var ms = end_date.getTime() - start_date.getTime()
      if(ms > 0){
        this.setData({
          canFixDisPatch: false
        })
      }
      this.setData({
        data: res.data
      })
      wx.setNavigationBarTitle({
        title: res.data.orderStatusValue
      })
    })
  },
  bigAction(e) {
    let index = e.currentTarget.dataset.index
    wx.previewImage({
      urls: this.data.data.demandImgUrls,
      current: this.data.data.demandImgUrls[index]
    })
  },
  choosegujia() {
    let that = this
    wx.navigateTo({
      url: '../process/choose?id=' + this.data.id,
      events: {
        updateData: function (e) {
          let eventChannel = that.getOpenerEventChannel()
          eventChannel.emit("updateData")
          that.getData()
        }
      }
    })
  },
  fixgujia(){
    let that = this
    wx.navigateTo({
      url: '../process/choose?fix=1&id=' + this.data.id,
      events: {
        updateData: function (e) {
          let eventChannel = that.getOpenerEventChannel()
          eventChannel.emit("updateData")
          that.getData()
        }
      }
    })
  },
  cancelAction() {
    let that = this
    wx.showModal({
      title: "温馨提示",
      content: "确认取消订单？",
      cancelColor: "#3E3E3E",
      confirmColor: "#437CFD",
      success(e) {
        if (e.confirm) {
          that.cancelWork()
        }
      }
    })
  },
  cancelWork() {
    let that = this
    wxPost(ApiOrderCancel, {
      "id": this.data.id
    }).then(res => {
      wx.showToast({
        title: '取消成功',
        success() {
          let eventChannel = that.getOpenerEventChannel()
          eventChannel.emit("updateData")
          wx.navigateBack()
        }
      })
    })
  },
  sendOrder() {
    this.setData({
      overlayVisible: true
    })
  },
  cancelOverlay() {
    this.setData({
      overlayVisible: false
    })
  },
  overlayAction() {
    if (!this.data.price) {
      showToast("请输入金额")
      return
    }
    let that = this
    wx.showLoading({
      title: '请求中',
    })
    wxPost(ApiSendOrder, {
      "id": this.data.id,
      "price": this.data.price
    }).then(res => {
      showToast("发送成功")
      that.setData({
        overlayVisible: false
      })
      that.getData()
      let eventChannel = that.getOpenerEventChannel()
      eventChannel.emit("updateData")
    })
  },
  payAction() {
    let orderId = this.data.id
    wx.showLoading({
      title: '请求中',
    })
    wxGet(ApiOrderPay + orderId).then(res => {
      this.payWork(res.data.payParam)
    })
  },
  payWork(payParam) {
    let that = this
    wx.requestPayment({
      nonceStr: payParam.nonceStr,
      package: payParam.package,
      paySign: payParam.paySign,
      signType: payParam.signType,
      timeStamp: payParam.timeStamp,
      success(e) {
        that.getData()
        let eventChannel = that.getOpenerEventChannel()
        eventChannel.emit("updateData")
      },
      fail(e) {}
    })
  },
  dispatchAction(){
    let that = this
    wx.navigateTo({
      url: '../process/dispatch?id=' + this.data.id,
      events: {
        updateData: function (e) {
          let eventChannel = that.getOpenerEventChannel()
          eventChannel.emit("updateData")
          that.getData()
        }
      }
    })
  },
  fixDispatchAction(){
    let that = this
    wx.navigateTo({
      url: '../process/dispatch?fix=1&id=' + this.data.id,
      events: {
        updateData: function (e) {
          let eventChannel = that.getOpenerEventChannel()
          eventChannel.emit("updateData")
          that.getData()
        }
      }
    })
  },
  serviceAction(){
    wx.switchTab({
      url: '/pages/service/service',
    })
  },
  finishAction(e){
    let that = this
    wx.showModal({
      title: "温馨提示",
      content: "确认完成该订单？",
      cancelColor: "#3E3E3E",
      confirmColor: "#437CFD",
      success(e) {
        if (e.confirm) {
          that.finishWork()
        }
      }
    })
  },
  finishWork(){
    let that = this
    wxPost(ApiFinishOrder,{"id":this.data.id}).then(res=>{
      showToast("操作成功")
      let eventChannel = that.getOpenerEventChannel()
      eventChannel.emit("updateData")
      that.getData()
    })
  }
})