const { ApiDefAddrInfo, ApiOrder } = require("../../http/api");
const { wxUpload, wxGet, wxPost } = require("../../http/network");
const { showToast } = require("../../utils/common");

// pages/order/order-service.js
Page({

  /**
   * 页面的初始数据
   */
  data: {
    serviceInfo: null,
    expectArrivalTime: "",
    num: 1,
    urls: [],
    visible: false,
    read: false,
    demandDesc: "",
    addressId: 0,
    addrData: null,
    tips: ""
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad(options) {
    this.picker = this.selectComponent("#picker")
    let infoStr = decodeURIComponent(options.info)
    this.setData({
      serviceInfo: JSON.parse(infoStr)
    })
    this.getAddrDef()
   
  },
  getAddrDef(){
    let that = this
    wxGet(ApiDefAddrInfo).then(res=>{
      if(res.data.id){
        that.setData({
          addressId: res.data.id,
          addrData: res.data,
          tips: res.data.tips
        })
      }
    })
  },
  timeOpen() {
    this.picker.showDialog();
  },
  confirm(e) {
    this.setData({
      expectArrivalTime: e.detail.selectDate
    })
  },
  subtractAction(){
    if(this.data.num == 1)return
    this.setData({
      num: this.data.num - 1
    })
  },
  addAction(){
    this.setData({
      num: this.data.num + 1
    })
  },
  chooseImage(){
    this.setData({
      visible: true
    })
  },
  dismissChoose(){
    this.setData({
      visible: false
    })
  },
  takePhoto(){
    let that = this
    wx.chooseMedia({
      count: 1,
      mediaType: ['image'],
      sourceType: ['camera'],
      camera: 'back',
      success(res) {
        let path = res.tempFiles[0].tempFilePath
        that.uploadFileAction(path)
      }
    })
    this.dismissChoose()
  },
  openPhoto(){
    let that = this
    wx.chooseMedia({
      count: 1,
      mediaType: ['image'],
      sourceType: ['album'],
      camera: 'back',
      success(res) {
        let path = res.tempFiles[0].tempFilePath
        that.uploadFileAction(path)
      }
    })
    this.dismissChoose()
  },
  uploadFileAction(path){
    wx.showLoading({
      title: '上传中',
    })
    let that = this
    wxUpload(path,"IMG").then(res=>{
      showToast("上传成功")
      let urls = that.data.urls
      urls.push(res.data.urls[0])
      that.setData({
        urls
      })
    }).finally(()=>{
      wx.hideLoading()
    })
  },
  deleteAction(e){
    let index = e.currentTarget.dataset.index
    console.log(index)
    let urls = this.data.urls
    urls.splice(index,1)
    this.setData({
      urls
    })
  },
  readAction(){
    let read = this.data.read
    this.setData({
      read: !read
    })
  },
  descChange(e){
    this.setData({
      demandDesc: e.detail.value
    })
  },
  changeAddr(){
    let that = this
    wx.navigateTo({
      url: '../address/index?path=order',
      events:{
        getBackData:res=>{
          that.setData({
            addrData: res,
            addressId: res.id
          })
        }
      }
    })
  },
  orderSubmit(){
    if(this.data.addressId == 0){
      showToast("请选择服务地址")
      return
    }

    if(this.data.expectArrivalTime == ""){
      showToast("请选择上门时间")
      return
    }

    if(this.data.urls.length == 0){
      showToast("请上传图片")
      return
    }

    if(this.data.demandDesc.length == 0){
      showToast("请输入需求说明")
      return
    }
    if(!this.data.read){
      showToast("请勾选我已阅读协议")
      return
    }
    let that = this
    wx.requestSubscribeMessage({
      tmplIds: ["ygS2cgt5SrFQ8yKe6VzF3tMYTTkbGDSHwXiJRPlExJE","AFA-i9A_MrzxQzogJJot3EXY4j5bfOe4WFpl9VvA8Jg"],
      complete(e){
        that.orderRequest()
      }
    })
  },
  orderRequest(){
    let date = this.data.expectArrivalTime
    let param = {
      addressId: this.data.addressId,
      demandDesc: this.data.demandDesc,
      expectArrivalTime: date,
      num: this.data.num,
      readAgreement: true,
      subclassId: this.data.serviceInfo.id,
      urls: this.data.urls
    }
    wx.showLoading()
    let that = this
    wxPost(ApiOrder,param).then(res=>{
      wx.hideLoading()
      wx.showToast({
        icon: "none",
        title: "预约成功",
        success(){
          let data = {
            name: that.data.addrData.name,
            phone: that.data.addrData.phone,
            serviceName: that.data.serviceInfo.serviceName,
            num: that.data.num
          }
          wx.redirectTo({
            url: './order-result?data=' + encodeURIComponent(JSON.stringify(data)),
          })
        }
      })
    }).catch(()=>{
      wx.hideLoading()
    })
  },
  agreementAction(){
    wx.navigateTo({
      url: '../service/service-agreement',
    })
  }
})